# mayako-core

lightweight framework for interaction technique prototyping in hci reseach


## Documentation
- published at [GitHub Pages](https://vairasza.github.io/mayako-core/)


## Sources:
- Deploy the Documentation to GitHub Pages:
    https://tomasfarias.dev/articles/sphinx-docs-with-poetry-and-github-pages/
